
	      .SYMBOLS
	      .ORG	 B000H
	      .PUBLIC ERROR_SW
	      .PUBLIC H,C,R
	      .PUBLIC RH,RC,RR
	      .PUBLIC FormatC,FormatH,FormatR
	      .PUBLIC Motor_On,Motor_Off
	      .PUBLIC Reset,Specify,Select_Data_Rate,Recalibrate,Seek
	      .PUBLIC Read,Write,Format_Track

;********************************************************************************
;*********    PORT DEFINITION	 ************************************************
;********************************************************************************
Digit_Output_Reg	equ	  $43F2
Main_Status_Reg		equ	  $43F4
Data_Rate_Sel_Reg	equ	  $43F4
Data_Reg		equ	  $43F5
Digit_Input_Reg		equ	  $43F7


FDCBuffer		equ	  $600
FDCBuffer1		equ	  $700
;********************************************************************************
;*********    VARIABLE DEFINITION    ********************************************
;********************************************************************************
DELAY_0	      EQU	0A0H ;B
DELAY_1	      EQU	0A1H ;B
DELAY_2	      EQU	0A2H ;B
H	      EQU	0A3H ;B
C	      EQU	0A4H ;B
R	      EQU	0A5H ;B
CMD	      EQU	0A6H ;B
READ_ADD      EQU	0A8H ;W
READ_ADD1     EQU	0AAH ;W
FormatC	      EQU	0ACH ;B
FormatH	      EQU	0ADH ;B
FormatR	      EQU	0AEH ;B
RC	      EQU	0B0H ;B
RH	      EQU	0B1H ;B
RR	      EQU	0B2H ;B
ERROR_SW      EQU	0B3H ;B











;********************************************************************************
;*********    Delay    **********************************************************
;********************************************************************************
;*Parameters
;*	     DELAY_0: low 8bit.
;*	     DELAY_1: mid 8bit.
;*	     DELAY_2: high 8bit.
;********************************************************************************
;*Description
;*	      Wait for time.
;********************************************************************************
Delay
	      INC	DELAY_0
	      INC	DELAY_1
	      INC	DELAY_2
Delay_01
	      NOP
	      DEC	DELAY_0
	      BNE	Delay_01
	      DEC	DELAY_1
	      BNE	Delay_01
	      DEC	DELAY_2
	      BNE	Delay_01
	      RTS
;********************************************************************************










;********************************************************************************
;*********    Out_FDC_Cmd    ****************************************************
;********************************************************************************
;*Parameters
;*	      CMD: command codes
;********************************************************************************
;*Description
;*	      Test main	status register	bit7
;*	      bit7=1 data port is ready.
;*	      bit7=0 data port is not ready continue wait.
;********************************************************************************
Out_FDC_Cmd
	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032
	      LDA	Main_Status_Reg
	      AND	#C0H
	      CMP	#80H
	      BNE	Out_FDC_Cmd
	      LDA	CMD
	      STA	Data_Reg
	      SEI
	      LDA	#11111111B
	      STA	$4032
	      RTS
;********************************************************************************










;********************************************************************************
;*********    Motor_On	  *******************************************************
;********************************************************************************
;*Parameters
;*	     no	parameter
;********************************************************************************
;*Description
;*	      Motor power on.
;********************************************************************************
Motor_On
	      JSR	Reset
	      LDA	#25H
	      STA	Digit_Output_Reg
	      RTS
;********************************************************************************










;********************************************************************************
;*********    Motor_Off	   ******************************************************
;********************************************************************************
;*Parameters
;*	     no	parameter
;********************************************************************************
;*Description
;*	      Motor power off.
;********************************************************************************
Motor_Off
	      LDA	#05H
	      STA	Digit_Output_Reg
	      RTS
;********************************************************************************










;********************************************************************************
;********     Select_Data_Rate	   **********************************************
;********************************************************************************
;*Parameters
;*	      no parameter
;********************************************************************************
;*Description
;*	      Define data transfer rates.
;*	      00H: 500k	bps
;*	      01H: 300k	bps
;*	      02H: 250k	bps
;********************************************************************************
Select_Data_Rate
	      LDA	#00H
	      STA	Digit_Input_Reg
	      RTS
;********************************************************************************










;********************************************************************************
;*********    Specify	 ********************************************************
;********************************************************************************
;*Parameters
;*	      no parameter
;********************************************************************************
;*Description
;*	      The initial values of the	HUT,HLT,SRT.
;********************************************************************************
Specify
	      LDA	#03H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#BFH
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#03H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      RTS
;********************************************************************************










;********************************************************************************
;*********    Reset    **********************************************************
;********************************************************************************
;*Parameters
;*	      no parameter
;********************************************************************************
;*Description
;*	      Reset FDC, active	low.
;********************************************************************************
Reset
	      LDA	#21H
	      STA	Digit_Output_Reg
	      LDA	#25H
	      STA	Digit_Output_Reg
	      RTS
;********************************************************************************










;********************************************************************************
;*********    Recalibrate    ****************************************************
;********************************************************************************
;*Parameters
;*	      no parameter
;********************************************************************************
;*Description
;*	      Retracts the read/write head to the track	0 position.
;********************************************************************************
Recalibrate
	      LDA	#07H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#01H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#00H
	      STA	DELAY_0
	      LDA	#80H
	      STA	DELAY_1
	      LDA	#01H
	      STA	DELAY_2
	      JSR	Delay

	      RTS
;********************************************************************************










;********************************************************************************
;*********    Seek    ***********************************************************
;********************************************************************************
;*Parameters
;*	      H: head number
;*	      C: cylinder number
;********************************************************************************
;*Description
;*	      Controls the read/write head movement from one track to another.
;********************************************************************************
Seek
	      LDA	#0FH
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	H
	      CLC
	      ROL	A
	      ROL	A
	      ORA	#01H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	C
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#00H
	      STA	DELAY_0
	      LDA	#80H
	      STA	DELAY_1
	      LDA	#01H
	      STA	DELAY_2
	      JSR	Delay
	      RTS
;********************************************************************************










;********************************************************************************
;*********    Read    ***********************************************************
;********************************************************************************
;*Parameters
;*	      H: head number.
;*	      C: cylinder number.
;*	      R: sector	number.
;********************************************************************************
;*Description
;*	      Read a sector from your define H,C,R to define FDCBuffer.
;********************************************************************************
Read

	      LDA	#<FDCBuffer
	      STA	READ_ADD
	      LDA	#>FDCBuffer
	      STA	READ_ADD+1
	      LDA	#<FDCBuffer1
	      STA	READ_ADD1
	      LDA	#>FDCBuffer1
	      STA	READ_ADD1+1


	      LDA	#E6H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	H
	      CLC
	      ROL	A
	      ROL	A
	      ORA	#01H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	C
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	R
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#02H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#12H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#1BH
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#FFH
	      STA	CMD
	      JSR	Out_FDC_Cmd

	      LDA	#80H
	      STA	DELAY_0
	      LDA	#01H
	      STA	DELAY_1
	      LDA	#00H
	      STA	DELAY_2
	      JSR	Delay
	      LDY	#00H
	      LDX	#C0H

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032
Read_01
	      CPX	Main_Status_Reg
	      BPL	Read_01

	      LDA	Data_Reg
	      STA	(READ_ADD),Y
	      INY
	      BNE	Read_01

Read_02
	      CPX	Main_Status_Reg
	      BPL	Read_02

	      LDA	Data_Reg
	      STA	(READ_ADD1),Y
	      INY
	      BNE	Read_02

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#80H
	      STA	DELAY_0
	      LDA	#00H
	      STA	DELAY_1
	      LDA	#00H
	      STA	DELAY_2
	      JSR	Delay

	      RTS
;********************************************************************************










;********************************************************************************
;*********    Write    **********************************************************
;********************************************************************************
;*Parameters
;*	      H: head number.
;*	      C: cylinder number.
;*	      R: sector	number.
;********************************************************************************
;*Description
;*	      Write a sector from your define FDCBuffer	to define H,C,R.
;********************************************************************************
Write

	      LDA	#<FDCBuffer
	      STA	READ_ADD
	      LDA	#>FDCBuffer
	      STA	READ_ADD+1
	      LDA	#<FDCBuffer1
	      STA	READ_ADD1
	      LDA	#>FDCBuffer1
	      STA	READ_ADD1+1


	      LDA	#C5H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	H
	      CLC
	      ROL	A
	      ROL	A
	      ORA	#01H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	C
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	R
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#02H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#12H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#1BH
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#FFH
	      STA	CMD
	      JSR	Out_FDC_Cmd

	      LDA	#80H
	      STA	DELAY_0
	      LDA	#01H
	      STA	DELAY_1
	      LDA	#00H
	      STA	DELAY_2
	      JSR	Delay
	      LDY	#00H
	      LDX	#80H

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032
Write_01
	      CPX	Main_Status_Reg
	      BPL	Write_01

	      LDA	(READ_ADD),Y
	      STA	Data_Reg
	      INY
	      BNE	Write_01

Write_02
	      CPX	Main_Status_Reg
	      BPL	Write_02

	      LDA	(READ_ADD1),Y
	      STA	Data_Reg
	      INY
	      BNE	Write_02

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#80H
	      STA	DELAY_0
	      LDA	#00H
	      STA	DELAY_1
	      LDA	#00H
	      STA	DELAY_2
	      JSR	Delay

	      RTS
;********************************************************************************










;********************************************************************************
;*********    Format_Track    ***************************************************
;********************************************************************************
;*Parameters
;*	      FormatH: head number.
;*	      FormatC: cylinder	number.
;********************************************************************************
;*Description
;*	      This command is used to format an	entire track.
;********************************************************************************
Format_Track
	      LDX	#80H
	      LDA	#4DH
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	FormatH
	      CLC
	      ROL	A
	      ROL	A
	      ORA	#01H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#02H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#12H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#54H
	      STA	CMD
	      JSR	Out_FDC_Cmd
	      LDA	#F6H
	      STA	CMD
	      JSR	Out_FDC_Cmd

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0101
	      CPX	Main_Status_Reg
	      BPL	?Track_0101
	      LDA	FormatC
	      STA	Data_Reg
?Track_0102
	      CPX	Main_Status_Reg
	      BPL	?Track_0102
	      LDA	FormatH
	      STA	Data_Reg
?Track_0103
	      CPX	Main_Status_Reg
	      BPL	?Track_0103
	      LDA	#01H
	      STA	Data_Reg
?Track_0104
	      CPX	Main_Status_Reg
	      BPL	?Track_0104
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0201
	      CPX	Main_Status_Reg
	      BPL	?Track_0201
	      LDA	FormatC
	      STA	Data_Reg
?Track_0202
	      CPX	Main_Status_Reg
	      BPL	?Track_0202
	      LDA	FormatH
	      STA	Data_Reg
?Track_0203
	      CPX	Main_Status_Reg
	      BPL	?Track_0203
	      LDA	#02H
	      STA	Data_Reg
?Track_0204
	      CPX	Main_Status_Reg
	      BPL	?Track_0204
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0301
	      CPX	Main_Status_Reg
	      BPL	?Track_0301
	      LDA	FormatC
	      STA	Data_Reg
?Track_0302
	      CPX	Main_Status_Reg
	      BPL	?Track_0302
	      LDA	FormatH
	      STA	Data_Reg
?Track_0303
	      CPX	Main_Status_Reg
	      BPL	?Track_0303
	      LDA	#03H
	      STA	Data_Reg
?Track_0304
	      CPX	Main_Status_Reg
	      BPL	?Track_0304
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0401
	      CPX	Main_Status_Reg
	      BPL	?Track_0401
	      LDA	FormatC
	      STA	Data_Reg
?Track_0402
	      CPX	Main_Status_Reg
	      BPL	?Track_0402
	      LDA	FormatH
	      STA	Data_Reg
?Track_0403
	      CPX	Main_Status_Reg
	      BPL	?Track_0403
	      LDA	#04H
	      STA	Data_Reg
?Track_0404
	      CPX	Main_Status_Reg
	      BPL	?Track_0404
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0501
	      CPX	Main_Status_Reg
	      BPL	?Track_0501
	      LDA	FormatC
	      STA	Data_Reg
?Track_0502
	      CPX	Main_Status_Reg
	      BPL	?Track_0502
	      LDA	FormatH
	      STA	Data_Reg
?Track_0503
	      CPX	Main_Status_Reg
	      BPL	?Track_0503
	      LDA	#05H
	      STA	Data_Reg
?Track_0504
	      CPX	Main_Status_Reg
	      BPL	?Track_0504
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0601
	      CPX	Main_Status_Reg
	      BPL	?Track_0601
	      LDA	FormatC
	      STA	Data_Reg
?Track_0602
	      CPX	Main_Status_Reg
	      BPL	?Track_0602
	      LDA	FormatH
	      STA	Data_Reg
?Track_0603
	      CPX	Main_Status_Reg
	      BPL	?Track_0603
	      LDA	#06H
	      STA	Data_Reg
?Track_0604
	      CPX	Main_Status_Reg
	      BPL	?Track_0604
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0701
	      CPX	Main_Status_Reg
	      BPL	?Track_0701
	      LDA	FormatC
	      STA	Data_Reg
?Track_0702
	      CPX	Main_Status_Reg
	      BPL	?Track_0702
	      LDA	FormatH
	      STA	Data_Reg
?Track_0703
	      CPX	Main_Status_Reg
	      BPL	?Track_0703
	      LDA	#07H
	      STA	Data_Reg
?Track_0704
	      CPX	Main_Status_Reg
	      BPL	?Track_0704
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0801
	      CPX	Main_Status_Reg
	      BPL	?Track_0801
	      LDA	FormatC
	      STA	Data_Reg
?Track_0802
	      CPX	Main_Status_Reg
	      BPL	?Track_0802
	      LDA	FormatH
	      STA	Data_Reg
?Track_0803
	      CPX	Main_Status_Reg
	      BPL	?Track_0803
	      LDA	#08H
	      STA	Data_Reg
?Track_0804
	      CPX	Main_Status_Reg
	      BPL	?Track_0804
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_0901
	      CPX	Main_Status_Reg
	      BPL	?Track_0901
	      LDA	FormatC
	      STA	Data_Reg
?Track_0902
	      CPX	Main_Status_Reg
	      BPL	?Track_0902
	      LDA	FormatH
	      STA	Data_Reg
?Track_0903
	      CPX	Main_Status_Reg
	      BPL	?Track_0903
	      LDA	#09H
	      STA	Data_Reg
?Track_0904
	      CPX	Main_Status_Reg
	      BPL	?Track_0904
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1001
	      CPX	Main_Status_Reg
	      BPL	?Track_1001
	      LDA	FormatC
	      STA	Data_Reg
?Track_1002
	      CPX	Main_Status_Reg
	      BPL	?Track_1002
	      LDA	FormatH
	      STA	Data_Reg
?Track_1003
	      CPX	Main_Status_Reg
	      BPL	?Track_1003
	      LDA	#0AH
	      STA	Data_Reg
?Track_1004
	      CPX	Main_Status_Reg
	      BPL	?Track_1004
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1101
	      CPX	Main_Status_Reg
	      BPL	?Track_1101
	      LDA	FormatC
	      STA	Data_Reg
?Track_1102
	      CPX	Main_Status_Reg
	      BPL	?Track_1102
	      LDA	FormatH
	      STA	Data_Reg
?Track_1103
	      CPX	Main_Status_Reg
	      BPL	?Track_1103
	      LDA	#0BH
	      STA	Data_Reg
?Track_1104
	      CPX	Main_Status_Reg
	      BPL	?Track_1104
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1201
	      CPX	Main_Status_Reg
	      BPL	?Track_1201
	      LDA	FormatC
	      STA	Data_Reg
?Track_1202
	      CPX	Main_Status_Reg
	      BPL	?Track_1202
	      LDA	FormatH
	      STA	Data_Reg
?Track_1203
	      CPX	Main_Status_Reg
	      BPL	?Track_1203
	      LDA	#0CH
	      STA	Data_Reg
?Track_1204
	      CPX	Main_Status_Reg
	      BPL	?Track_1204
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1301
	      CPX	Main_Status_Reg
	      BPL	?Track_1301
	      LDA	FormatC
	      STA	Data_Reg
?Track_1302
	      CPX	Main_Status_Reg
	      BPL	?Track_1302
	      LDA	FormatH
	      STA	Data_Reg
?Track_1303
	      CPX	Main_Status_Reg
	      BPL	?Track_1303
	      LDA	#0DH
	      STA	Data_Reg
?Track_1304
	      CPX	Main_Status_Reg
	      BPL	?Track_1304
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1401
	      CPX	Main_Status_Reg
	      BPL	?Track_1401
	      LDA	FormatC
	      STA	Data_Reg
?Track_1402
	      CPX	Main_Status_Reg
	      BPL	?Track_1402
	      LDA	FormatH
	      STA	Data_Reg
?Track_1403
	      CPX	Main_Status_Reg
	      BPL	?Track_1403
	      LDA	#0EH
	      STA	Data_Reg
?Track_1404
	      CPX	Main_Status_Reg
	      BPL	?Track_1404
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1501
	      CPX	Main_Status_Reg
	      BPL	?Track_1501
	      LDA	FormatC
	      STA	Data_Reg
?Track_1502
	      CPX	Main_Status_Reg
	      BPL	?Track_1502
	      LDA	FormatH
	      STA	Data_Reg
?Track_1503
	      CPX	Main_Status_Reg
	      BPL	?Track_1503
	      LDA	#0FH
	      STA	Data_Reg
?Track_1504
	      CPX	Main_Status_Reg
	      BPL	?Track_1504
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1601
	      CPX	Main_Status_Reg
	      BPL	?Track_1601
	      LDA	FormatC
	      STA	Data_Reg
?Track_1602
	      CPX	Main_Status_Reg
	      BPL	?Track_1602
	      LDA	FormatH
	      STA	Data_Reg
?Track_1603
	      CPX	Main_Status_Reg
	      BPL	?Track_1603
	      LDA	#10H
	      STA	Data_Reg
?Track_1604
	      CPX	Main_Status_Reg
	      BPL	?Track_1604
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1701
	      CPX	Main_Status_Reg
	      BPL	?Track_1701
	      LDA	FormatC
	      STA	Data_Reg
?Track_1702
	      CPX	Main_Status_Reg
	      BPL	?Track_1702
	      LDA	FormatH
	      STA	Data_Reg
?Track_1703
	      CPX	Main_Status_Reg
	      BPL	?Track_1703
	      LDA	#11H
	      STA	Data_Reg
?Track_1704
	      CPX	Main_Status_Reg
	      BPL	?Track_1704
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#FFH
	      STA	$4035
	      LDA	#11101111B
	      STA	$4034
	      CLI
	      LDA	#01111111B
	      STA	$4032

?Track_1801
	      CPX	Main_Status_Reg
	      BPL	?Track_1801
	      LDA	FormatC
	      STA	Data_Reg
?Track_1802
	      CPX	Main_Status_Reg
	      BPL	?Track_1802
	      LDA	FormatH
	      STA	Data_Reg
?Track_1803
	      CPX	Main_Status_Reg
	      BPL	?Track_1803
	      LDA	#12H
	      STA	Data_Reg
?Track_1804
	      CPX	Main_Status_Reg
	      BPL	?Track_1804
	      LDA	#02H
	      STA	Data_Reg

	      SEI
	      LDA	#11111111B
	      STA	$4032

	      LDA	#00H
	      STA	DELAY_0
	      LDA	#10H
	      STA	DELAY_1
	      LDA	#00H
	      STA	DELAY_2
	      JSR	Delay

	      RTS
;********************************************************************************
